@@ -1,9 +1,6 @@
-/*	$OpenBSD: head.c,v 1.5 1996/06/08 19:48:26 christos Exp $	*/
-/*	$NetBSD: head.c,v 1.5 1996/06/08 19:48:26 christos Exp $	*/
-
 /*
- * Copyright (c) 1980, 1993
- *	The Regents of the University of California.  All rights reserved.
+ * Copyright (c) 1980 Regents of the University of California.
+ * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -35,15 +32,11 @@
  */
 
 #ifndef lint
-#if 0
-static char sccsid[] = "@(#)head.c	8.1 (Berkeley) 6/6/93";
-#else
-static char rcsid[] = "$OpenBSD: head.c,v 1.5 1996/06/08 19:48:26 christos Exp $";
-#endif
+/*static char sccsid[] = "from: @(#)head.c	5.7 (Berkeley) 6/1/90";*/
+static char rcsid[] = "$Id: head.c,v 1.2 1993/08/01 18:13:04 mycroft Exp $";
 #endif /* not lint */
 
 #include "rcv.h"
-#include "extern.h"
 
 /*
  * Mail -- a mail program
@@ -56,7 +49,6 @@ static char rcsid[] = "$OpenBSD: head.c,v 1.5 1996/06/08 19:48:26 christos Exp $
  * Return true if yes.  Note the extreme pains to
  * accomodate all funny formats.
  */
-int
 ishead(linebuf)
 	char linebuf[];
 {
@@ -84,7 +76,6 @@ ishead(linebuf)
 }
 
 /*ARGSUSED*/
-void
 fail(linebuf, reason)
 	char linebuf[], reason[];
 {
@@ -102,7 +93,6 @@ fail(linebuf, reason)
  * pointers into the copied line in the passed headline
  * structure.  Actually, it scans.
  */
-void
 parse(line, hl, pbuf)
 	char line[], pbuf[];
 	register struct headline *hl;
@@ -146,7 +136,7 @@ copyin(src, space)
 	char *top;
 
 	top = cp = *space;
-	while ((*cp++ = *src++) != '\0')
+	while (*cp++ = *src++)
 		;
 	*space = cp;
 	return (top);
@@ -170,25 +160,22 @@ copyin(src, space)
  * 'N'	A new line
  */
 char ctype[] = "Aaa Aaa O0 00:00:00 0000";
-char ctype_without_secs[] = "Aaa Aaa O0 00:00 0000";
+char ctype2[] = "Aaa Aaa O0 00:00 0000";
 char tmztype[] = "Aaa Aaa O0 00:00:00 AAA 0000";
-char tmztype_without_secs[] = "Aaa Aaa O0 00:00 AAA 0000";
+char tmztype2[] = "Aaa Aaa O0 00:00 AAA 0000";
 
-int
 isdate(date)
 	char date[];
 {
 
-	return cmatch(date, ctype_without_secs) || 
-	       cmatch(date, tmztype_without_secs) || 
-	       cmatch(date, ctype) || cmatch(date, tmztype);
+	return cmatch(date, ctype) || cmatch(date, tmztype)
+	  || cmatch(date, ctype2) || cmatch(date, tmztype2);
 }
 
 /*
  * Match the given string (cp) against the given template (tp).
  * Return 1 if they match, 0 if they don't
  */
-int
 cmatch(cp, tp)
 	register char *cp, *tp;
 {
