@@ -1,6 +1,6 @@
 /*
- * Copyright (c) 1980, 1993
- *	The Regents of the University of California.  All rights reserved.
+ * Copyright (c) 1980 Regents of the University of California.
+ * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -32,7 +32,8 @@
  */
 
 #ifndef lint
-static char sccsid[] = "@(#)names.c	8.1 (Berkeley) 6/6/93";
+/*static char sccsid[] = "from: @(#)names.c	5.16 (Berkeley) 6/25/90";*/
+static char rcsid[] = "$Id: names.c,v 1.2 1993/08/01 18:13:00 mycroft Exp $";
 #endif /* not lint */
 
 /*
@@ -42,8 +43,6 @@ static char sccsid[] = "@(#)names.c	8.1 (Berkeley) 6/6/93";
  */
 
 #include "rcv.h"
-#include <fcntl.h>
-#include "extern.h"
 
 /*
  * Allocate a single element of a name list,
@@ -53,7 +52,6 @@ static char sccsid[] = "@(#)names.c	8.1 (Berkeley) 6/6/93";
 struct name *
 nalloc(str, ntype)
 	char str[];
-	int ntype;
 {
 	register struct name *np;
 
@@ -90,7 +88,6 @@ tailof(name)
 struct name *
 extract(line, ntype)
 	char line[];
-	int ntype;
 {
 	register char *cp;
 	register struct name *top, *np, *t;
@@ -119,7 +116,6 @@ extract(line, ntype)
 char *
 detract(np, ntype)
 	register struct name *np;
-	int ntype;
 {
 	register int s;
 	register char *cp, *top;
@@ -197,7 +193,7 @@ yankword(ap, wbuf)
 		for (cp2 = wbuf; *cp && (*cp2++ = *cp++) != '>';)
 			;
 	else
-		for (cp2 = wbuf; *cp && !strchr(" \t,(", *cp); *cp2++ = *cp++)
+		for (cp2 = wbuf; *cp && !index(" \t,(", *cp); *cp2++ = *cp++)
 			;
 	*cp2 = '\0';
 	return cp;
@@ -219,8 +215,8 @@ outof(names, fo, hp)
 {
 	register int c;
 	register struct name *np, *top;
-	time_t now;
-	char *date, *fname;
+	time_t now, time();
+	char *date, *fname, *ctime();
 	FILE *fout, *fin;
 	int ispipe;
 	extern char tempEdit[];
@@ -259,7 +255,6 @@ outof(names, fo, hp)
 				(void) Fclose(fout);
 				goto cant;
 			}
-			(void) fcntl(image, F_SETFD, 1);
 			fprintf(fout, "From %s %s", myname, date);
 			puthead(hp, fout, GTO|GSUBJECT|GCC|GNL);
 			while ((c = getc(fo)) != EOF)
@@ -346,7 +341,6 @@ cant:
  * If any of the network metacharacters precedes any slashes, it can't
  * be a filename.  We cheat with .'s to allow path names like ./...
  */
-int
 isfileaddr(name)
 	char *name;
 {
@@ -409,7 +403,6 @@ struct name *
 gexpand(nlist, gh, metoo, ntype)
 	struct name *nlist;
 	struct grouphead *gh;
-	int metoo, ntype;
 {
 	struct group *gp;
 	struct grouphead *ngh;
@@ -631,7 +624,6 @@ put(list, node)
  * Determine the number of undeleted elements in
  * a name list and return it.
  */
-int
 count(np)
 	register struct name *np;
 {
@@ -678,7 +670,6 @@ delname(np, name)
  */
 
 /*
-void
 prettyprint(name)
 	struct name *name;
 {
