@@ -1,6 +1,6 @@
 /*
- * Copyright (c) 1989, 1993
- *	The Regents of the University of California.  All rights reserved.
+ * Copyright (c) 1989 Regents of the University of California.
+ * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -30,15 +30,21 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- *	@(#)pathnames.h	8.1 (Berkeley) 6/6/93
+ *	from: @(#)pathnames.h	5.14 (Berkeley) 6/19/91
+ *	$Id: pathnames.h,v 1.2 1993/08/01 18:13:17 mycroft Exp $
  */
 
+#include <paths.h>
+
 /* mail installed files */
 #define _PATH_HELP	"/usr/lib/mail.help"
 #define _PATH_TILDE	"/usr/lib/mail.tildehelp"
 #define _PATH_MASTER_RC	"/etc/mail.rc"
 
 /* mail runtime files */
+#ifndef _PATH_MAIL_LOG
+#define _PATH_MAIL_LOG	"/var/adm/maillog"
+#endif
 #ifndef _PATH_MAILDIR
 #define _PATH_MAILDIR	"/var/spool/mail"
 #endif
