@@ -1,6 +1,6 @@
 /*
- * Copyright (c) 1980, 1993
- *	The Regents of the University of California.  All rights reserved.
+ * Copyright (c) 1980 Regents of the University of California.
+ * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -30,7 +30,8 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- *	@(#)rcv.h	8.1 (Berkeley) 6/6/93
+ *	from: @(#)rcv.h	5.5 (Berkeley) 6/1/90
+ *	$Id: rcv.h,v 1.2 1993/08/01 18:13:16 mycroft Exp $
  */
 
 /*
@@ -43,11 +44,17 @@
 #include "def.h"
 #include "glob.h"
 
-#if !defined(sig_t) && !(BSD > 43)
-typedef void (*sig_t)();
-#endif
-
-#ifdef __GNUC__
+#if defined(__GNUC__) && defined(__GNU_LIBRARY__)
 #undef  NULL
 #define NULL 0
-#endif /* __GNUC__ */
+#endif /* gnu */
+
+#ifdef __linux__
+/*  new versions of libc do this automatically when you compile with
+ *  -D_BSD_SOURCE.  sadly, pre-4.5 versions screwed it up.
+ */
+#undef  setjmp
+#define setjmp(env)		sigsetjmp ((env), 1)
+#undef  longjmp
+#define longjmp(env, val)	siglongjmp ((env), (val))
+#endif /* __linux__ */
